{

=pod

=head1 NAME

Userland::weblogUpdates

=head1 SUMMARY

 my $blog = Userland::weblogUpdates->new();
 $blog->ping("My Blog Name","http://myblog.com");

=head1 DESCRIPTION

This package implements methods supported by the Userland weblogUpdates framework.

=cut

package Userland::weblogUpdate;
use strict;

use constant HOST => "http://rpc.weblogs.com";
use constant PATH => "/RPC2";
use constant PING => "weblogUpdates.ping";

use Carp;
use Frontier::Client;

=pod

=head1 PUBLIC METHODS

=head2 Userland::weblogUpdates->new(%args)

Valid arguments are 

=over 4

=item debug I<int>

=back

=cut

sub new {
    my $pkg = shift;
    
    my $self = {};
    bless $self;

    $self->init(@_) || return undef;

    return $self;
}

sub init {
    my $self = shift;
    my $args = { @_ };
    return $self->_xmlrpc(debug=>$args->{'debug'});
}

=pod

=head2 $pkg->ping($name,$uri)

Returns true or false.

=cut

sub ping {
    my $self = shift;
    my $name = shift;
    my $uri  = shift;

    my $ping = undef;

    eval { 
	$ping = $self->_xmlrpc()->call(
				       PING,
				       $self->_xmlrpc()->string($name),
				       $self->_xmlrpc()->string($uri),
				       );
    };
    
    if ($@) {
	carp $@;
	return 0;
    }

    return $ping;
}

sub _xmlrpc {
    my $self = shift;
    my $args = { @_ };

    if (! $self->{"_xmlrpc"}) {
	$self->{"_xmlrpc"} = Frontier::Client->new(url=>HOST.PATH,debug=>$args->{'debug'})
	    || &{ carp $!; return 0; };
    }

    return $self->{"_xmlrpc"};
}

=pod

=head1 TO DO 

=over 4

=item 

SOAP support

=item

Better error handling.

=back

=head1 VERSION

0.1

=head1 DATE

October 01, 2001

=head1 CHANGES

=head2 0.1

=over 4

=item

Initial revision

=back

=head1 SEE ALSO

L<Frontier::Client>

http://www.xmlrpc.com/weblogsCom

=head1 LICENSE

Copyright 2001 Aaron Straup Cope.

This is free software, you may use it and distribute it under the same terms as Perl itself.

=cut

return 1;

}
